@@ -1,6 +1,6 @@
 <?php
 /*
-$Id: conflogin.php,v 1.47 2010/02/06 11:50:26 gruberroland Exp $
+$Id: conflogin.php,v 1.51 2010/10/11 17:52:30 gruberroland Exp $
 
   This code is part of LDAP Account Manager (http://www.ldap-account-manager.org/)
   Copyright (C) 2003 - 2010  Roland Gruber
@@ -62,7 +62,15 @@ echo $_SESSION['header'];
 				echo _("Login");
 			?>
 		</title>
-		<link rel="stylesheet" type="text/css" href="../../style/layout.css">
+	<?php 
+		// include all CSS files
+		$cssDirName = dirname(__FILE__) . '/../../style';
+		$cssDir = dir($cssDirName);
+		while ($cssEntry = $cssDir->read()) {
+			if (substr($cssEntry, strlen($cssEntry) - 4, 4) != '.css') continue;
+			echo "<link rel=\"stylesheet\" type=\"text/css\" href=\"../../style/" . $cssEntry . "\">\n";
+		}
+	?>
 		<link rel="shortcut icon" type="image/x-icon" href="../../graphics/favicon.ico">
 	</head>
 	<body>
@@ -70,24 +78,39 @@ echo $_SESSION['header'];
 			// include all JavaScript files
 			$jsDirName = dirname(__FILE__) . '/../lib';
 			$jsDir = dir($jsDirName);
+			$jsFiles = array();
 			while ($jsEntry = $jsDir->read()) {
 				if (substr($jsEntry, strlen($jsEntry) - 3, 3) != '.js') continue;
+				$jsFiles[] = $jsEntry;
+			}
+			sort($jsFiles);
+			foreach ($jsFiles as $jsEntry) {
 				echo "<script type=\"text/javascript\" src=\"../lib/" . $jsEntry . "\"></script>\n";
 			}
 			// set focus on password field
-			echo "<script type=\"text/javascript\" language=\"javascript\">\n";
-			echo "<!--\n";
-			echo "window.onload = function() {\n";
-				echo "loginField = document.getElementsByName('passwd')[0];\n";
-				echo "loginField.focus();\n";
-			echo "}\n";
-			echo "//-->\n";
-			echo "</script>\n";
-		?>
-		<p align="center"><a href="http://www.ldap-account-manager.org/" target="_blank">
-			<img src="../../graphics/banner.jpg" border=1 alt="LDAP Account Manager"></a>
-		</p>
-		<hr><br><br>
+			?>
+			<script type="text/javascript" language="javascript">
+			<!--
+			window.onload = function() {
+				loginField = document.getElementsByName('passwd')[0];
+				loginField.focus();
+			}
+			jQuery(document).ready(function() {
+				jQuery('#submitButton').button();
+			});
+			//-->
+			</script>
+		<table border=0 width="100%" class="lamHeader ui-corner-all">
+			<tr>
+				<td align="left" height="30">
+					<a class="lamHeader" href="http://www.ldap-account-manager.org/" target="new_window">&nbsp;<img src="../../graphics/logo32.png" width=24 height=24 class="align-middle" alt="LDAP Account Manager">&nbsp;&nbsp;LDAP Account Manager</a>
+				</td>
+			<td align="right" height=20>
+				<a href="../login.php"><IMG alt="configuration" src="../../graphics/undo.png">&nbsp;<?php echo _("Back to login") ?></a>
+			</td>
+			</tr>
+		</table>
+		<br><br>
 		<!-- form to change existing profiles -->
 		<form action="confmain.php" method="post">
 		<table align="center" border="2" rules="none" bgcolor="white">
@@ -132,8 +155,8 @@ echo $_SESSION['header'];
 						else echo "<select disabled size=1 name=\"filename\">\n<option></option>\n</select>\n";
 						if (sizeof($files) > 0) echo "<input type=\"password\" name=\"passwd\">\n";
 						else echo "<input disabled type=\"password\" name=\"passwd\">\n";
-						if (sizeof($files) > 0) echo "<input type=\"submit\" name=\"submit\" value=\"" . _("Ok") . "\">\n";
-						else echo "<input disabled type=\"submit\" name=\"submit\" value=\"" . _("Ok") . "\">&nbsp;\n";
+						if (sizeof($files) > 0) echo "<button id=\"submitButton\" class=\"smallPadding\" name=\"submit\">" . _("Ok") . "</button>\n";
+						else echo "<button id=\"submitButton\" class=\"smallPadding\" name=\"submit\" disabled>" . _("Ok") . "</button>&nbsp;\n";
 						// help link
 						printHelpLink(getHelp('', '200'), '200');
 					?>
@@ -154,12 +177,8 @@ echo $_SESSION['header'];
 		</table>
 		</form>
 
-		<p><br><br><br><br><br></p>
+		<p><br><br></p>
 
-		<!-- back to login page -->
-		<p>
-			<a href="../login.php"> <?php echo _("Back to Login"); ?> </a>
-		</p>
 
 	</body>
 </html>
