@@ -1,6 +1,6 @@
 <?php
 /*
-$Id: confmain.php,v 1.116 2010/02/20 17:26:10 gruberroland Exp $
+$Id: confmain.php,v 1.122 2010/09/13 20:05:58 gruberroland Exp $
 
   This code is part of LDAP Account Manager (http://www.ldap-account-manager.org/)
   Copyright (C) 2003 - 2010  Roland Gruber
@@ -120,19 +120,40 @@ $tabindex = 1;
 echo $_SESSION['header'];
 
 echo ("<title>" . _("LDAP Account Manager Configuration") . "</title>\n");
-echo ("<link rel=\"stylesheet\" type=\"text/css\" href=\"../../style/layout.css\">\n");
+
+// include all CSS files
+$cssDirName = dirname(__FILE__) . '/../../style';
+$cssDir = dir($cssDirName);
+while ($cssEntry = $cssDir->read()) {
+	if (substr($cssEntry, strlen($cssEntry) - 4, 4) != '.css') continue;
+	echo "<link rel=\"stylesheet\" type=\"text/css\" href=\"../../style/" . $cssEntry . "\">\n";
+}
+
 echo "<link rel=\"shortcut icon\" type=\"image/x-icon\" href=\"../../graphics/favicon.ico\">\n";
 echo ("</head>\n");
 echo ("<body onload=\"configLoginMethodChanged()\">\n");
 // include all JavaScript files
 $jsDirName = dirname(__FILE__) . '/../lib';
 $jsDir = dir($jsDirName);
+$jsFiles = array();
 while ($jsEntry = $jsDir->read()) {
 	if (substr($jsEntry, strlen($jsEntry) - 3, 3) != '.js') continue;
+	$jsFiles[] = $jsEntry;
+}
+sort($jsFiles);
+foreach ($jsFiles as $jsEntry) {
 	echo "<script type=\"text/javascript\" src=\"../lib/" . $jsEntry . "\"></script>\n";
 }
-echo ("<p align=\"center\"><a href=\"http://www.ldap-account-manager.org/\" target=\"new_window\">".
-	"<img src=\"../../graphics/banner.jpg\" border=1 alt=\"LDAP Account Manager\"></a></p>\n<hr>\n<p>&nbsp;</p>\n");
+?>
+		<table border=0 width="100%" class="lamHeader ui-corner-all">
+			<tr>
+				<td align="left" height="30">
+					<a class="lamHeader" href="http://www.ldap-account-manager.org/" target="new_window">&nbsp;<img src="../../graphics/logo32.png" width=24 height=24 class="align-middle" alt="LDAP Account Manager">&nbsp;&nbsp;LDAP Account Manager</a>
+				</td>
+			</tr>
+		</table>
+		<br>
+<?php
 
 if (!$conf->isWritable()) {
 	StatusMessage('WARN', 'The config file is not writable.', 'Your changes cannot be saved until you make the file writable for the webserver user.');
@@ -149,84 +170,70 @@ if (sizeof($errorsToDisplay) > 0) {
 
 // display formular
 echo ("<form action=\"confmain.php\" method=\"post\">\n");
-echo "<table border=0 width=\"100%\" style=\"border-collapse: collapse;\">\n";
-echo "<tr valign=\"top\"><td style=\"border-bottom: 1px solid;padding:0px;\" colspan=2>";
-// show tabs
-echo "<table width=\"100%\" border=0 style=\"border-collapse: collapse;\">";
-echo "<tr>\n";
-	$buttonSpace = '&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;';
-	// general settings
-	echo "<td class=\"settingsTab\">\n";
-	echo "<table class=\"settingsTab\" width=\"100%\">\n";
-	echo "<tr><td class=\"settingsActiveTab\" onclick=\"document.getElementsByName('generalSettingsButton')[0].click();\"";
-	echo " align=\"center\">\n";
-	$buttonStyle = 'background-image: url(../../graphics/bigTools.png);';
-	echo "<input style=\"" . $buttonStyle . "\" name=\"generalSettingsButton\" type=\"submit\" value=\"" . $buttonSpace . _('General settings') . "\"";
-	echo ">\n";
-	echo "</td></tr></table>\n";
-	echo '</td>';
-	// account types
-	echo "<td class=\"settingsTab\">\n";
-	echo "<table class=\"settingsTab\" width=\"100%\">\n";
-	echo "<tr><td onclick=\"document.getElementsByName('edittypes')[0].click();\"";
-	echo " align=\"center\">\n";
-	$buttonStyle = 'background-image: url(../../graphics/gear.png);';
-	echo "<input style=\"" . $buttonStyle . "\" name=\"edittypes\" type=\"submit\" value=\"" . $buttonSpace . _('Account types') . "\"";
-	echo ">\n";
-	echo "</td></tr></table>\n";
-	echo '</td>';
-	// module selection
-	echo "<td class=\"settingsTab\">\n";
-	echo "<table class=\"settingsTab\" width=\"100%\">\n";
-	echo "<tr><td onclick=\"document.getElementsByName('editmodules')[0].click();\"";
-	echo " align=\"center\">\n";
-	$buttonStyle = 'background-image: url(../../graphics/modules.png);';
-	echo "<input style=\"" . $buttonStyle . "\" name=\"editmodules\" type=\"submit\" value=\"" . $buttonSpace . _('Modules') . "\"";
-	echo ">\n";
-	echo "</td></tr></table>\n";
-	echo '</td>';
-	// module settings
-	echo "<td class=\"settingsTab\">\n";
-	echo "<table class=\"settingsTab\" width=\"100%\">\n";
-	echo "<tr><td onclick=\"document.getElementsByName('moduleSettings')[0].click();\"";
-	echo " align=\"center\">\n";
-	$buttonStyle = 'background-image: url(../../graphics/moduleSettings.png);';
-	echo "<input style=\"" . $buttonStyle . "\" name=\"moduleSettings\" type=\"submit\" value=\"" . $buttonSpace . _('Module settings') . "\"";
-	echo ">\n";
-	echo "</td></tr></table>\n";
-	echo '</td>';
-	echo "<td width=\"100%\">&nbsp;</td>";
-	// spacer
-	echo "<td width=\"100%\">&nbsp;</td>";
-	// save button
-	echo "<td class=\"settingsTab\">\n";
-	echo "<table class=\"settingsTab\" width=\"100%\">\n";
-	echo "<tr><td onclick=\"document.getElementsByName('saveSettings')[0].click();\"";
-	echo " align=\"center\">\n";
-	$buttonStyle = 'background-image: url(../../graphics/pass.png);';
-	echo "<input style=\"" . $buttonStyle . "\" name=\"saveSettings\" type=\"submit\" value=\"" . $buttonSpace . _('Save') . "\"";
-	echo ">\n";
-	echo "</td></tr></table>\n";
-	echo '</td>';
-	// cancel button
-	echo "<td class=\"settingsTab\">\n";
-	echo "<table class=\"settingsTab\" width=\"100%\">\n";
-	echo "<tr><td onclick=\"document.getElementsByName('cancelSettings')[0].click();\"";
-	echo " align=\"center\">\n";
-	$buttonStyle = 'background-image: url(../../graphics/fail.png);';
-	echo "<input style=\"" . $buttonStyle . "\" name=\"cancelSettings\" type=\"submit\" value=\"" . $buttonSpace . _('Cancel') . "\"";
-	echo ">\n";
-	echo "</td></tr></table>\n";
-	echo '</td>';
-	echo "</tr></table>\n";		
-// end tabs
-echo "</td></tr>\n";
 
-echo "<tr><td><br><br>\n";
-echo ("<fieldset><legend><img align=\"middle\" src=\"../../graphics/profiles.png\" alt=\"profiles.png\"> <b>" . _("Server settings") . "</b></legend><br>\n");
+echo '<div style="text-align: right;">';
+echo "<button id=\"saveButton\" name=\"saveSettings\" type=\"submit\">" . _('Save') . "</button>";
+echo "&nbsp;";
+echo "<button id=\"cancelButton\" name=\"cancelSettings\" type=\"submit\">" . _('Cancel') . "</button>";
+echo "<br><br>\n";
+echo '</div>';
+
+// hidden submit buttons which are clicked by tabs
+echo "<div style=\"display: none;\">\n";
+	echo "<input name=\"generalSettingsButton\" type=\"submit\" value=\" \">";
+	echo "<input name=\"edittypes\" type=\"submit\" value=\" \">";
+	echo "<input name=\"editmodules\" type=\"submit\" value=\" \">";
+	echo "<input name=\"moduleSettings\" type=\"submit\" value=\" \">";
+echo "</div>\n";
+	
+// tabs
+echo '<div class="ui-tabs ui-widget ui-widget-content ui-corner-all">';
+
+echo '<ul class="ui-tabs-nav ui-helper-reset ui-helper-clearfix ui-widget-header ui-corner-all">';
+echo '<li id="generalSettingsButton" class="ui-state-default ui-corner-top">';
+	echo '<a href="#" onclick="document.getElementsByName(\'generalSettingsButton\')[0].click();"><img src="../../graphics/tools.png" alt=""> ';
+	echo _('General settings') . '</a>';
+echo '</li>';
+echo '<li id="edittypes" class="ui-state-default ui-corner-top">';
+	echo '<a href="#" onclick="document.getElementsByName(\'edittypes\')[0].click();"><img src="../../graphics/gear.png" alt=""> ';
+	echo _('Account types') . '</a>';
+echo '</li>';
+echo '<li id="editmodules" class="ui-state-default ui-corner-top">';
+	echo '<a href="#" onclick="document.getElementsByName(\'editmodules\')[0].click();"><img src="../../graphics/modules.png" alt=""> ';
+	echo _('Modules') . '</a>';
+echo '</li>';
+echo '<li id="moduleSettings" class="ui-state-default ui-corner-top">';
+	echo '<a href="#" onclick="document.getElementsByName(\'moduleSettings\')[0].click();"><img src="../../graphics/modules.png" alt=""> ';
+	echo _('Module settings') . '</a>';
+echo '</li>';
+echo '</ul>';
+
+?>
+
+<script type="text/javascript">
+jQuery(document).ready(function() {
+	jQuery('#generalSettingsButton').addClass('ui-tabs-selected');
+	jQuery('#generalSettingsButton').addClass('ui-state-active');
+	jQuery('#saveButton').button({
+        icons: {
+      	  primary: 'saveButton'
+    	}
+	});
+	jQuery('#cancelButton').button({
+        icons: {
+    	  primary: 'cancelButton'
+  	}
+	});
+});
+</script>
+
+<div class="ui-tabs-panel ui-widget-content ui-corner-bottom">
+<?php
+
+echo ("<fieldset><legend><img align=\"middle\" src=\"../../graphics/profiles.png\" alt=\"profiles.png\"> " . _("Server settings") . "</legend><br>\n");
 echo ("<table border=0>");
 // serverURL
-echo ("<tr><td align=\"right\"><b>" . _("Server address") . " *: </b></td>".
+echo ("<tr><td align=\"right\">" . _("Server address") . " * </td>".
 	"<td align=\"left\">".
 	"<input tabindex=\"$tabindex\" size=50 type=\"text\" name=\"serverurl\" value=\"" . $conf->get_ServerURL() . "\">".
 	"</td>\n");
@@ -235,7 +242,7 @@ printHelpLink(getHelp('', '201'), '201');
 echo "</td></tr>\n";
 $tabindex++;
 // use TLS
-echo "<tr><td align=\"right\"><b>" . _("Activate TLS") . ": </b></td>\n";
+echo "<tr><td align=\"right\">" . _("Activate TLS") . " </td>\n";
 echo "<td align=\"left\">\n";
 echo "<select tabindex=\"$tabindex\" size=1 name=\"useTLS\">";
 $useTLS = $conf->getUseTLS();
@@ -258,8 +265,8 @@ $tabindex++;
 echo ("<tr><td colspan=3>&nbsp;</td></tr>");
 
 // tree suffix
-echo ("<tr><td align=\"right\"><b>".
-	_("Tree suffix") . ": </b></td>".
+echo ("<tr><td align=\"right\">".
+	_("Tree suffix") . " </td>".
 	"<td><input tabindex=\"$tabindex\" size=50 type=\"text\" name=\"sufftree\" value=\"" . $conf->get_Suffix('tree') . "\"></td>\n");
 echo "<td>";
 printHelpLink(getHelp('', '203'), '203');
@@ -270,8 +277,8 @@ $tabindex++;
 echo ("<tr><td colspan=3>&nbsp;</td></tr>");
 
 // LDAP cache timeout
-echo ("<tr><td align=\"right\"><b>".
-	_("Cache timeout") . ": </b></td>".
+echo ("<tr><td align=\"right\">".
+	_("Cache timeout") . " </td>".
 	"<td><select tabindex=\"$tabindex\" name=\"cachetimeout\">\n<option selected>".$conf->get_cacheTimeout()."</option>\n");
 if ($conf->get_cacheTimeout() != 0) echo("<option>0</option>\n");
 if ($conf->get_cacheTimeout() != 1) echo("<option>1</option>\n");
@@ -291,8 +298,8 @@ array(0, '-'), array(100, 100), array(500, 500),
 array(1000, 1000), array(5000, 5000), array(10000, 10000),
 array(50000, 50000), array(100000, 100000)
 );
-echo ("<tr><td align=\"right\"><b>".
-	_("LDAP search limit") . ": </b></td>".
+echo ("<tr><td align=\"right\">".
+	_("LDAP search limit") . " </td>".
 	"<td><select tabindex=\"$tabindex\" name=\"searchLimit\">\n");
 for ($i = 0; $i < sizeof($searchLimitOptions); $i++) {
 	$selected = "";
@@ -313,8 +320,8 @@ if (isLAMProVersion()) {
 	echo ("<tr><td colspan=3>&nbsp;</td></tr>");
 	
 	// access level
-	echo ("<tr><td align=\"right\"><b>".
-		_("Access level") . ": </b></td>".
+	echo ("<tr><td align=\"right\">".
+		_("Access level") . " </td>".
 		"<td><select tabindex=\"$tabindex\" name=\"accessLevel\">\n");
 	if ($conf->getAccessLevel() == LAMConfig::ACCESS_ALL) {
 		echo("<option selected value=" . LAMConfig::ACCESS_ALL . ">" . _('Write access') . "</option>\n");
@@ -346,12 +353,12 @@ echo ("</fieldset>");
 
 echo ("<br>");
 
-echo ("<fieldset><legend><img align=\"middle\" src=\"../../graphics/language.png\" alt=\"language.png\"> <b>" . _("Language settings") . "</b></legend><br>\n");
+echo ("<fieldset><legend><img align=\"middle\" src=\"../../graphics/language.png\" alt=\"language.png\"> " . _("Language settings") . "</legend><br>\n");
 echo ("<table border=0>\n");
 
 // language
 echo ("<tr>");
-echo ("<td><b>" . _("Default language") . ":</b></td><td>\n");
+echo ("<td>" . _("Default language") . "</td><td>\n");
 // read available languages
 $languagefile = "../../config/language";
 if(is_file($languagefile))
@@ -391,24 +398,24 @@ echo ("</fieldset>\n");
 echo ("<br>\n");
 
 // lamdaemon settings
-echo ("<fieldset><legend><img align=\"middle\" src=\"../../graphics/lamdaemon.png\" alt=\"lamdaemon.png\"> <b>" . _("Lamdaemon settings") . "</b></legend><br>\n");
+echo ("<fieldset><legend><img align=\"middle\" src=\"../../graphics/lamdaemon.png\" alt=\"lamdaemon.png\"> " . _("Lamdaemon settings") . "</legend><br>\n");
 echo ("<table border=0>\n");
 
-echo ("<tr><td align=\"right\"><b>".
-	_("Server list") . ": </b></td>".
+echo ("<tr><td align=\"right\">".
+	_("Server list") . " </td>".
 	"<td><input tabindex=\"$tabindex\" size=50 type=\"text\" name=\"scriptservers\" value=\"" . $conf->get_scriptServers(false) . "\"></td>\n");
 $tabindex++;
 echo "<td>";
 printHelpLink(getHelp('', '218'), '218');
 echo "</td></tr>\n";
-echo ("<tr><td align=\"right\"><b>".
-	_("Path to external script") . ": </b></td>".
+echo ("<tr><td align=\"right\">".
+	_("Path to external script") . " </td>".
 	"<td><input tabindex=\"$tabindex\" size=50 type=\"text\" name=\"scriptpath\" value=\"" . $conf->get_scriptPath() . "\"></td>\n");
 $tabindex++;
 echo "<td>";
 printHelpLink(getHelp('', '210'), '210');
 echo "</td></tr>\n";
-echo "<tr><td align=\"right\"><b>". _("Rights for the home directory") . ": </b></td>\n";
+echo "<tr><td align=\"right\">". _("Rights for the home directory") . " </td>\n";
 $owr = "";
 $oww = "";
 $owe = "";
@@ -457,12 +464,32 @@ echo ("</fieldset>\n");
 
 echo ("<br>\n");
 
+// LAM Pro settings
+if (isLAMProVersion()) {
+
+	$pwdMailContent = new htmlTable();
+	
+	$pwdMailFrom = new htmlTableExtendedInputField(_('From address'), 'pwdResetMail_from', $conf->getLamProMailFrom(), '550');
+	$pwdMailContent->addElement($pwdMailFrom, true);
+	
+	$pwdMailSubject = new htmlTableExtendedInputField(_('Subject'), 'pwdResetMail_subject', $conf->getLamProMailSubject(), '551');
+	$pwdMailContent->addElement($pwdMailSubject, true);
+	
+	$pwdMailBody = new htmlTableExtendedInputTextarea('pwdResetMail_body', $conf->getLamProMailText(), 50, 4, _('Text'), '552');
+	$pwdMailContent->addElement($pwdMailBody, true);
+	
+	$pwdMailFieldset = new htmlFieldset($pwdMailContent, _("Password mail settings"), '../../graphics/mailBig.png');
+	parseHtml(null, $pwdMailFieldset, array(), true, $tabindex, 'config');
+
+	echo ("<br>\n");
+}
+
 // security setings
-echo ("<fieldset><legend><img align=\"middle\" src=\"../../graphics/security.png\" alt=\"security.png\"> <b>" . _("Security settings") . "</b></legend><br>\n");
+echo ("<fieldset><legend><img align=\"middle\" src=\"../../graphics/security.png\" alt=\"security.png\"> " . _("Security settings") . "</legend><br>\n");
 echo ("<table border=0>\n");
 // login method
-echo ("<tr><td align=\"right\"><b>".
-	_("Login method") . ": </b></td>".
+echo ("<tr><td align=\"right\">".
+	_("Login method") . " </td>".
 	"<td><select tabindex=\"$tabindex\" name=\"loginMethod\" onchange=\"configLoginMethodChanged()\">\n");
 if ($conf->getLoginMethod() == LAMConfig::LOGIN_LIST) {
 	echo("<option selected value=" . LAMConfig::LOGIN_LIST . ">" . _('Fixed list') . "</option>\n");
@@ -484,8 +511,7 @@ echo "</td></tr>\n";
 // admin list
 $adminText = implode("\n", explode(";", $conf->get_Adminstring()));
 echo "<tr id=\"trAdminList\"><td align=\"right\">\n";
-echo "<b>".
-	_("List of valid users") . " *: </b></td>".
+echo _("List of valid users") . " * </td>".
 	"<td><textarea tabindex=\"$tabindex\" name=\"admins\" cols=75 rows=3>" . $adminText . "</textarea></td>\n";
 echo "<td>";
 printHelpLink(getHelp('', '207'), '207');
@@ -493,8 +519,7 @@ echo "</td></tr>\n";
 $tabindex++;
 // login search suffix
 echo "<tr id=\"trLoginSearchSuffix\"><td align=\"right\">\n";
-echo "<b>".
-	_("LDAP suffix") . " *: </b></td>".
+echo _("LDAP suffix") . " * </td>".
 	"<td><input type=\"text\" tabindex=\"$tabindex\" name=\"loginSearchSuffix\" value=\"" . $conf->getLoginSearchSuffix() . "\"  size=50></td>\n";
 echo "<td>";
 printHelpLink(getHelp('', '221'), '221');
@@ -502,8 +527,7 @@ echo "</td></tr>\n";
 $tabindex++;
 // login search filter
 echo "<tr id=\"trLoginSearchFilter\"><td align=\"right\">\n";
-echo "<b>".
-	_("LDAP filter") . " *: </b></td>".
+echo _("LDAP filter") . " * </td>".
 	"<td><input type=\"text\" tabindex=\"$tabindex\" name=\"loginSearchFilter\" value=\"" . $conf->getLoginSearchFilter() . "\"  size=50></td>\n";
 echo "<td>";
 printHelpLink(getHelp('', '221'), '221');
@@ -513,26 +537,24 @@ $tabindex++;
 echo ("<tr><td colspan=3>&nbsp;</td></tr>\n");
 
 // new password
-echo ("<tr><td align=\"right\"><font color=\"red\"><b>".
-	_("New password") . ": </b></font></td>".
+echo ("<tr><td align=\"right\"><font color=\"red\">".
+	_("New password") . " </font></td>".
 	"<td align=\"left\"><input tabindex=\"$tabindex\" type=\"password\" name=\"passwd1\"></td>\n");
 $tabindex++;
 echo "<td rowspan=2>";
 printHelpLink(getHelp('', '212'), '212');
 echo "</td></tr>\n";
 // reenter password
-echo ("<tr><td align=\"right\"><font color=\"red\"><b>".
-	_("Reenter password") . ": </b></font></td>".
+echo ("<tr><td align=\"right\"><font color=\"red\">".
+	_("Reenter password") . " </font></td>".
 	"<td align=\"left\"><input tabindex=\"$tabindex\" type=\"password\" name=\"passwd2\"></td></tr>\n");
 $tabindex++;
 echo ("</table>\n");
 echo ("</fieldset>\n");
 
 echo ("<p>* = ". _("required") . "</p>");
-echo ("<p>&nbsp;</p>\n");
 
-echo '</td></tr></table>';
-echo ("</form>\n");
+echo ("</div></div></form>\n");
 echo ("</body>\n");
 echo ("</html>\n");
 
@@ -565,6 +587,11 @@ function checkInput() {
 	$conf->set_searchLimit($_POST['searchLimit']);
 	if (isLAMProVersion()) {
 		$conf->setAccessLevel($_POST['accessLevel']);
+		if (!$conf->setLamProMailFrom($_POST['pwdResetMail_from'])) {
+			$errors[] = array("ERROR", _("From address for password mails is invalid."), $_POST['pwdResetMail_from']);
+		}
+		$conf->setLamProMailSubject($_POST['pwdResetMail_subject']);
+		$conf->setLamProMailText($_POST['pwdResetMail_body']);
 	}
 	$adminText = $_POST['admins'];
 	$adminText = explode("\n", $adminText);
