@@ -1,9 +1,9 @@
 <?php
 /*
-$Id: index.php,v 1.9 2009/10/27 18:46:33 gruberroland Exp $
+$Id: index.php,v 1.11 2010/08/31 18:05:17 gruberroland Exp $
 
   This code is part of LDAP Account Manager (http://www.ldap-account-manager.org/)
-  Copyright (C) 2003 - 2006  Roland Gruber
+  Copyright (C) 2003 - 2010  Roland Gruber
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -50,14 +50,28 @@ echo $_SESSION['header'];
 				echo _("Configuration overview");
 			?>
 		</title>
-		<link rel="stylesheet" type="text/css" href="../../style/layout.css">
+	<?php 
+		// include all CSS files
+		$cssDirName = dirname(__FILE__) . '/../../style';
+		$cssDir = dir($cssDirName);
+		while ($cssEntry = $cssDir->read()) {
+			if (substr($cssEntry, strlen($cssEntry) - 4, 4) != '.css') continue;
+			echo "<link rel=\"stylesheet\" type=\"text/css\" href=\"../../style/" . $cssEntry . "\">\n";
+		}
+	?>
 		<link rel="shortcut icon" type="image/x-icon" href="../../graphics/favicon.ico">
 	</head>
 	<body>
-		<p align="center"><a href="http://www.ldap-account-manager.org/" target="_blank">
-			<img src="../../graphics/banner.jpg" border=1 alt="LDAP Account Manager"></a>
-		</p>
-		<hr>
+		<table border=0 width="100%" class="lamHeader ui-corner-all">
+			<tr>
+				<td align="left" height="30">
+					<a class="lamHeader" href="http://www.ldap-account-manager.org/" target="new_window">&nbsp;<img src="../../graphics/logo32.png" width=24 height=24 class="align-middle" alt="LDAP Account Manager">&nbsp;&nbsp;LDAP Account Manager</a>
+				</td>
+				<td align="right" height=20>
+					<a href="../login.php"><IMG alt="configuration" src="../../graphics/undo.png">&nbsp;<?php echo _("Back to login") ?></a>
+				</td>
+			</tr>
+		</table>
 		<br><br>
 		<fieldset>
 			<legend><b> <?php echo _("LAM configuration"); ?> </b></legend>
@@ -108,11 +122,7 @@ echo $_SESSION['header'];
 		?>
 		</TABLE>
 		</fieldset>
-		<p><br><br><br><br><br></p>
+		<p><br><br></p>
 
-		<!-- back to login page -->
-		<p>
-			<a href="../login.php"> <?php echo _("Back to Login"); ?> </a>
-		</p>
 	</body>
 </html>
