@@ -1,6 +1,6 @@
 <?php
 /*
-$Id: mainmanage.php,v 1.21 2010/05/28 08:48:57 gruberroland Exp $
+$Id: mainmanage.php,v 1.25 2010/10/11 17:52:30 gruberroland Exp $
 
   This code is part of LDAP Account Manager (http://www.ldap-account-manager.org/)
   Copyright (C) 2003 - 2010  Roland Gruber
@@ -134,21 +134,41 @@ echo $_SESSION['header'];
 				echo _("Edit general settings");
 			?>
 		</title>
-		<link rel="stylesheet" type="text/css" href="../../style/layout.css">
+	<?php 
+		// include all CSS files
+		$cssDirName = dirname(__FILE__) . '/../../style';
+		$cssDir = dir($cssDirName);
+		while ($cssEntry = $cssDir->read()) {
+			if (substr($cssEntry, strlen($cssEntry) - 4, 4) != '.css') continue;
+			echo "<link rel=\"stylesheet\" type=\"text/css\" href=\"../../style/" . $cssEntry . "\">\n";
+		}
+	?>
 		<link rel="shortcut icon" type="image/x-icon" href="../../graphics/favicon.ico">
 	</head>
 	<body>
-		<p align="center"><a href="http://www.ldap-account-manager.org/" target="_blank">
-			<img src="../../graphics/banner.jpg" border=1 alt="LDAP Account Manager"></a>
-		</p>
-		<hr><br>
+		<table border=0 width="100%" class="lamHeader ui-corner-all">
+			<tr>
+				<td align="left" height="30">
+					<a class="lamHeader" href="http://www.ldap-account-manager.org/" target="new_window">&nbsp;<img src="../../graphics/logo32.png" width=24 height=24 class="align-middle" alt="LDAP Account Manager">&nbsp;&nbsp;LDAP Account Manager</a>
+				</td>
+				<td align="right" height=20>
+					<a href="../login.php"><IMG alt="configuration" src="../../graphics/undo.png">&nbsp;<?php echo _("Back to login") ?></a>
+				</td>
+			</tr>
+		</table>
+		<br>
 
 <?php
 // include all JavaScript files
 $jsDirName = dirname(__FILE__) . '/../lib';
 $jsDir = dir($jsDirName);
+$jsFiles = array();
 while ($jsEntry = $jsDir->read()) {
 	if (substr($jsEntry, strlen($jsEntry) - 3, 3) != '.js') continue;
+	$jsFiles[] = $jsEntry;
+}
+sort($jsFiles);
+foreach ($jsFiles as $jsEntry) {
 	echo "<script type=\"text/javascript\" src=\"../lib/" . $jsEntry . "\"></script>\n";
 }
 
@@ -169,7 +189,7 @@ if (!$cfg->isWritable()) {
 		<table border="0" align="center">
 		<tr><td>
 		<fieldset>
-			<legend><b> <?php echo _("Security settings"); ?> </b></legend>
+			<legend> <?php echo _("Security settings"); ?> </legend>
 			<br>
 			<table cellspacing="0" border="0">
 				<!-- session timeout -->
@@ -216,7 +236,7 @@ if (!$cfg->isWritable()) {
 		</fieldset>
 		<BR>
 		<fieldset>
-			<legend><b> <?php echo _("Password policy"); ?> </b></legend>
+			<legend> <?php echo _("Password policy"); ?> </legend>
 			<br>
 			<table cellspacing="0" border="0">
 			<?php
@@ -255,7 +275,7 @@ if (!$cfg->isWritable()) {
 		</fieldset>
 		<BR>
 		<fieldset>
-			<legend><b> <?php echo _("Logging"); ?> </b></legend>
+			<legend> <?php echo _("Logging"); ?> </legend>
 			<br>
 			<table cellspacing="0" border="0">
 				<!-- log level -->
@@ -339,7 +359,7 @@ if (!$cfg->isWritable()) {
 		</fieldset>
 		<BR>
 		<fieldset>
-			<legend><b> <?php echo _("Change master password"); ?> </b></legend>
+			<legend> <?php echo _("Change master password"); ?> </legend>
 			<br>
 			<table cellspacing="0" border="0">
 				<!-- set master password -->
@@ -373,9 +393,15 @@ if (!$cfg->isWritable()) {
 				<TD>
 					<BR>
 					<?php if ($cfg->isWritable()) { ?>
-					<input type="submit" name="submit" value=" <?php echo _("Ok"); ?> ">
+					<button id="submitButton" name="submit" class="smallPadding"><?php echo _("Ok"); ?></button>
 					<?php } ?>
-					<input type="submit" name="cancel" value=" <?php echo _("Cancel"); ?> ">
+					<button id="cancelButton" name="cancel" class="smallPadding"><?php echo _("Cancel"); ?></button>
+					<script type="text/javascript" language="javascript">
+					jQuery(document).ready(function() {
+						jQuery('#submitButton').button();
+						jQuery('#cancelButton').button();
+					});
+					</script>
 				</TD>
 			</TR>
 			</table>
