@@ -1,9 +1,9 @@
 <?php
 /*
-$Id: profmanage.php,v 1.34 2010/01/01 17:39:38 gruberroland Exp $
+$Id: profmanage.php,v 1.40 2010/10/11 20:27:48 gruberroland Exp $
 
   This code is part of LDAP Account Manager (http://www.ldap-account-manager.org/)
-  Copyright (C) 2003 - 2009  Roland Gruber
+  Copyright (C) 2003 - 2010  Roland Gruber
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -52,27 +52,47 @@ echo $_SESSION['header'];
 				echo _("Profile management");
 			?>
 		</title>
-		<link rel="stylesheet" type="text/css" href="../../style/layout.css">
+	<?php 
+		// include all CSS files
+		$cssDirName = dirname(__FILE__) . '/../../style';
+		$cssDir = dir($cssDirName);
+		while ($cssEntry = $cssDir->read()) {
+			if (substr($cssEntry, strlen($cssEntry) - 4, 4) != '.css') continue;
+			echo "<link rel=\"stylesheet\" type=\"text/css\" href=\"../../style/" . $cssEntry . "\">\n";
+		}
+	?>
 		<link rel="shortcut icon" type="image/x-icon" href="../../graphics/favicon.ico">
 	</head>
 	<body>
-		<p align="center"><a href="http://www.ldap-account-manager.org/" target="_blank">
-			<img src="../../graphics/banner.jpg" border=1 alt="LDAP Account Manager"></a>
-		</p>
-		<hr><br>
+		<table border=0 width="100%" class="lamHeader ui-corner-all">
+			<tr>
+				<td align="left" height="30">
+					<a class="lamHeader" href="http://www.ldap-account-manager.org/" target="new_window">&nbsp;<img src="../../graphics/logo32.png" width=24 height=24 class="align-middle" alt="LDAP Account Manager">&nbsp;&nbsp;LDAP Account Manager</a>
+				</td>
+				<td align="right" height=20>
+					<a href="conflogin.php"><IMG alt="configuration" src="../../graphics/undo.png">&nbsp;<?php echo _("Back to profile login") ?></a>
+				</td>
+			</tr>
+		</table>
+		<br>
 
 <?php
 // include all JavaScript files
 $jsDirName = dirname(__FILE__) . '/../lib';
 $jsDir = dir($jsDirName);
+$jsFiles = array();
 while ($jsEntry = $jsDir->read()) {
 	if (substr($jsEntry, strlen($jsEntry) - 3, 3) != '.js') continue;
+	$jsFiles[] = $jsEntry;
+}
+sort($jsFiles);
+foreach ($jsFiles as $jsEntry) {
 	echo "<script type=\"text/javascript\" src=\"../lib/" . $jsEntry . "\"></script>\n";
 }
 
 $cfg = new LAMCfgMain();
 // check if submit button was pressed
-if ($_POST['submit']) {
+if (isset($_POST['submit'])) {
 	// check master password
 	if (!$cfg->checkPassword($_POST['passwd'])) {
 		$error = _("Master password is wrong!");
@@ -82,18 +102,26 @@ if ($_POST['submit']) {
 		if (preg_match("/^[a-z0-9_-]+$/i", $_POST['addprofile']) && !in_array($_POST['addprofile'], getConfigProfiles())) {
 			// check profile password
 			if ($_POST['addpassword'] && $_POST['addpassword2'] && ($_POST['addpassword'] == $_POST['addpassword2'])) {
-				// create new profile file
-				@copy("../../config/lam.conf_sample", "../../config/" . $_POST['addprofile'] . ".conf");
-				@chmod ("../../config/" . $_POST['addprofile'] . ".conf", 0600);
-				$file = is_file("../../config/" . $_POST['addprofile'] . ".conf");
-				if ($file) {
-					// load as config and write new password
-					$conf = new LAMConfig($_POST['addprofile']);
-					$conf->set_Passwd($_POST['addpassword']);
-					$conf->save();
-					$msg = _("Created new profile.");
+				// check if lam.conf_sample exists
+				if (!is_file("../../config/lam.conf_sample")) {
+					$error = "The file config/lam.conf_sample was not found. Please restore it.";				
+				}
+				else {
+					// create new profile file
+					@copy("../../config/lam.conf_sample", "../../config/" . $_POST['addprofile'] . ".conf");
+					@chmod ("../../config/" . $_POST['addprofile'] . ".conf", 0600);
+					$file = is_file("../../config/" . $_POST['addprofile'] . ".conf");
+					if ($file) {
+						// load as config and write new password
+						$conf = new LAMConfig($_POST['addprofile']);
+						$conf->set_Passwd($_POST['addpassword']);
+						$conf->save();
+						$msg = _("Created new profile.");
+					}
+					else {
+						$error = _("Unable to create new profile!");
+					}
 				}
-				else $error = _("Unable to create new profile!");
 			}
 			else $error = _("Profile passwords are different or empty!");
 		}
@@ -351,20 +379,20 @@ if (!isset($cfg->default)) {
 			&nbsp;
 			<input type="password" name="passwd">
 			&nbsp;
-			<input type="submit" name="submit" value=" <?php echo _("Ok"); ?> ">
+			<button id="submitButton" name="submit" class="smallPadding"><?php echo _("Ok"); ?></button>
 			&nbsp;
 			<?PHP
 				printHelpLink(getHelp('', '236'), '236');
 			?>
+			<script type="text/javascript" language="javascript">
+			jQuery(document).ready(function() {
+				jQuery('#submitButton').button();
+			});
+			</script>
 
 		</form>
 		<p><br></p>
 
-		<!-- back to login page -->
-		<p>
-			<a href="conflogin.php"> <?php echo _("Back to profile login"); ?> </a>
-		</p>
-
 	</body>
 </html>
 
