@@ -1,6 +1,6 @@
 <?php
 /*
-	$Id: delete.php,v 1.78 2010/02/15 17:36:45 gruberroland Exp $
+	$Id: delete.php,v 1.81 2010/10/12 17:49:18 gruberroland Exp $
 
 	This code is part of LDAP Account Manager (http://www.ldap-account-manager.org/)
 	Copyright (C) 2003 - 2006  Tilo Lutz
@@ -77,10 +77,9 @@ if (isset($_GET['type']) && isset($_SESSION['delete_dn'])) {
 	$_SESSION['account'] = new accountContainer($_GET['type'], 'account');
 	// Show HTML Page
 	include 'main_header.php';
+	echo "<div class=\"".$_GET['type']."list-bright smallPaddingContent\">";
+	echo "<br>\n";
 	echo "<form action=\"delete.php\" method=\"post\">\n";
-	echo "<fieldset class=\"".$_GET['type']."edit\"><legend><b>";
-	echo _('Please confirm:');
-	echo "</b></legend><br>\n";
 	echo "<input name=\"type\" type=\"hidden\" value=\"" . $_GET['type'] . "\">\n";
 	echo "<b>" . _("Do you really want to remove the following accounts?") . "</b>";
 	echo "<br><br>\n";
@@ -108,28 +107,34 @@ if (isset($_GET['type']) && isset($_SESSION['delete_dn'])) {
 	}
 	echo "</table>\n";
 	echo "<br>\n";
-	echo "<input name=\"delete\" type=\"submit\" value=\"" . _('Delete') . "\">&nbsp;\n";
-	echo "<input name=\"cancel\" type=\"submit\" value=\"" . _('Cancel') . "\">\n";
-	echo "</fieldset>\n";
+	echo "<button class=\"smallPadding\" name=\"delete\" id=\"submitButton\">" . _('Delete') . "</button>&nbsp;\n";
+	echo "<button class=\"smallPadding\" name=\"cancel\" id=\"cancelButton\">" . _('Cancel') . "</button>\n";
 	echo "</form>\n";
-	echo "</body>\n";
-	echo "</html>\n";
+	echo "</div>\n";
+	?>
+	<script type="text/javascript" language="javascript">
+	jQuery(document).ready(function() {
+		jQuery('#submitButton').button();
+		jQuery('#cancelButton').button();
+	});
+	</script>
+	<?php
+	include 'main_footer.php';
 }
 
-if ($_POST['cancel']) {
+if (isset($_POST['cancel'])) {
 	if (isset($_SESSION['delete_dn'])) unset($_SESSION['delete_dn']);
 	metaRefresh("lists/list.php?type=" . $_POST['type']);
 }
 
-if ($_POST['delete']) {
+if (isset($_POST['delete'])) {
 	// Show HTML Page
 	include 'main_header.php';
 	echo "<form action=\"delete.php\" method=\"post\">\n";
 	echo "<input name=\"type\" type=\"hidden\" value=\"" . $_POST['type'] . "\">\n";
-	echo "<fieldset class=\"".$_POST['type']."edit\"><legend><b>";
-	echo _('Deleting. Please stand by ...');
-	echo "</b></legend><br>\n";
-
+	echo "<div class=\"".$_POST['type']."list-bright smallPaddingContent\"><br>\n";
+	echo "<br>\n";
+	
 	// Delete dns
 	for ($m=0; $m<count($_SESSION['delete_dn']); $m++) {
 		// Set to true if an real error has happened
@@ -220,6 +225,7 @@ if ($_POST['delete']) {
 			echo sprintf(_('Deleted DN: %s'), $_SESSION['delete_dn'][$m]) . "<br>\n";
 			foreach ($errors as $error) StatusMessage($error[0], $error[1], $error[2]);
 			echo "<br>\n";
+			flush();
 		}
 		else {
 			echo sprintf(_('Error while deleting DN: %s'), $_SESSION['delete_dn'][$m]) . "<br>\n";
@@ -229,11 +235,17 @@ if ($_POST['delete']) {
 	}
 	$_SESSION['cache']->refresh_cache(true);
 	echo "<br>\n";
-	echo "<br><input name=\"cancel\" type=\"submit\" value=\"" . _('Back to list') . "\">\n";
-	echo "</fieldset>\n";
+	echo "<br><button class=\"smallPadding\" name=\"cancel\" id=\"backButton\">" . _('Back to list') . "</button>\n";
+	echo "</div>\n";
 	echo "</form>\n";
-	echo "</body>\n";
-	echo "</html>\n";
+	?>
+	<script type="text/javascript" language="javascript">
+	jQuery(document).ready(function() {
+		jQuery('#backButton').button();
+	});
+	</script>
+	<?php
+	include 'main_footer.php';
 
 }
 
@@ -268,6 +280,7 @@ function deleteDN($dn) {
 	}
 	else {
 		$errors[] = array ('ERROR', sprintf(_('Was unable to delete DN: %s.'), $dn), ldap_error($_SESSION['ldap']->server()));
+		return $errors;
 	}
 	// delete parent DN
 	$success = @ldap_delete($_SESSION['ldap']->server(), $dn);
