@@ -1,6 +1,6 @@
 <?php
 /*
-$Id: initsuff.php,v 1.24 2010/05/07 19:11:24 gruberroland Exp $
+$Id: initsuff.php,v 1.26 2010/10/24 13:53:44 gruberroland Exp $
 
   This code is part of LDAP Account Manager (http://www.ldap-account-manager.org/)
   Copyright (C) 2003 - 2010  Roland Gruber
@@ -150,18 +150,18 @@ if (isset($_POST['add_suff']) || isset($_POST['cancel'])) {
 			for ($i = 0; $i < sizeof($fail); $i++) {
 				StatusMessage("ERROR", _("Failed to create entry!") . "<br>" . $error[$i], $fail[$i]);
 			}
-			echo "</body></html>\n";
+			include 'main_footer.php';
 		}
 		else {
 			// print success message
 			StatusMessage("INFO", "", _("All changes were successful."));
-			echo "</body></html>\n";
+			include 'main_footer.php';
 		}
 	}
 	else {
 		// no suffixes were created
 		StatusMessage("INFO", "", _("No changes were made."));
-		echo "</body></html>\n";
+		include 'main_footer.php';
 	}
 	exit;
 }
@@ -173,18 +173,27 @@ $new_suff = str_replace("'", "", $new_suff);
 $new_suff = explode(";", $new_suff);
 
 include 'main_header.php';
-	echo "<p>&nbsp;</p>\n";
-	echo "<p><font color=\"red\"><b>" . _("The following suffix(es) are missing in LDAP. LAM can create them for you.") . "</b></font></p>\n";
-	echo "<p>&nbsp;</p>\n";
+	echo '<div class="userlist-bright smallPaddingContent">';
+	echo "<form action=\"initsuff.php\" method=\"post\">\n";
+	$container = new htmlTable();
+	$container->addElement(new htmlOutputText(_("The following suffix(es) are missing in LDAP. LAM can create them for you.")), true);
+	$container->addElement(new htmlSpacer(null, '10px'), true);
 	// print missing suffixes
 	for ($i = 0; $i < sizeof($new_suff); $i++) {
-		echo "<p><b>" . $new_suff[$i] . "</b></p>\n";
+		$container->addElement(new htmlOutputText($new_suff[$i]), true);
 	}
-	echo "<p>&nbsp;</p>\n";
-	echo "<form action=\"initsuff.php\" method=\"post\">\n";
-	echo "<input type=\"hidden\" name=\"new_suff\" value=\"" . implode(";", $new_suff) . "\">\n";
-	echo "<input type=\"submit\" name=\"add_suff\" value=\"" . _("Create") . "\">";
-	echo "<input type=\"submit\" name=\"cancel\" value=\"" . _("Cancel") . "\">";
-	echo "</form>\n";
-echo "</body></html>\n";
+	$container->addElement(new htmlSpacer(null, '10px'), true);
+
+	$buttonContainer = new htmlTable();
+	$buttonContainer->addElement(new htmlButton('add_suff', _("Create")));
+	$buttonContainer->addElement(new htmlButton('cancel', _("Cancel")));
+	$buttonContainer->addElement(new htmlHiddenInput('new_suff', implode(";", $new_suff)));
+	$container->addElement($buttonContainer);
+	
+	$tabindex = 1;
+	parseHtml(null, $container, array(), false, $tabindex, 'user');
+	
+	echo "</form><br>\n";
+	echo "</div>\n";
+include 'main_footer.php';
 ?>
