@@ -1,6 +1,6 @@
 <?php
 /*
-$Id: massBuildAccounts.php,v 1.19 2010/02/16 17:32:48 gruberroland Exp $
+$Id: massBuildAccounts.php,v 1.21 2010/10/24 13:53:44 gruberroland Exp $
 
   This code is part of LDAP Account Manager (http://www.ldap-account-manager.org/)
   Copyright (C) 2004 - 2010  Roland Gruber
@@ -84,6 +84,7 @@ if (isset($_GET['showldif'])) {
 }
 
 include 'main_header.php';
+echo '<div class="userlist-bright smallPaddingContent">';
 
 if ($_FILES['inputfile'] && ($_FILES['inputfile']['size'] > 0)) {
 	$selectedModules = explode(',', $_POST['selectedModules']);
@@ -191,18 +192,13 @@ if ($_FILES['inputfile'] && ($_FILES['inputfile']['size'] > 0)) {
 				$_SESSION['mass_scope'] = $_POST['scope'];
 				$_SESSION['mass_selectedModules'] = $selectedModules;
 				// show links for upload and LDIF export
-				echo "<h1 align=\"center\">" . _("LAM has checked your input and is now ready to create the accounts.") . "</h1>\n";
+				echo "<div class=\"title\">\n";
+				echo "<h2 class=\"titleText\">" . _("LAM has checked your input and is now ready to create the accounts.") . "</h2>\n";
+				echo "</div>";
 				echo "<p>&nbsp;</p>\n";
-				echo "<p align=\"center\">\n";
-				echo "<table align=\"center\" width=\"80%\"><tr>\n";
-					echo "<td align=\"center\" width=\"50%\">\n";
-					echo "<a href=\"massDoUpload.php\"><b>" . _("Upload accounts to LDAP") . "</b></a>";
-					echo "</td>\n";
-					echo "<td align=\"center\" width=\"50%\">\n";
-					echo "<a href=\"massBuildAccounts.php?showldif=true\"><b>" . _("Show LDIF file") . "</b></a>";
-					echo "</td>\n";
-				echo "</tr></table>\n";
-				echo "</p>\n";
+					echo "<a href=\"massDoUpload.php\">" . _("Upload accounts to LDAP") . "</a>";
+					echo "&nbsp;&nbsp;&nbsp;&nbsp;";
+					echo "<a href=\"massBuildAccounts.php?showldif=true\">" . _("Show LDIF file") . "</a>";
 			}
 		}
 	}
@@ -212,8 +208,7 @@ else {
 	echo '<br><a href="masscreate.php">' . _('Back') . '</a>';
 }
 
-echo "</body>\n";
-echo "</html>\n";
-
+echo '</div>';
+include 'main_footer.php';
 
 ?>
\ No newline at end of file
