@@ -1,6 +1,6 @@
 <?php
 /*
-$Id: masscreate.php,v 1.87 2010/05/19 19:22:29 gruberroland Exp $
+$Id: masscreate.php,v 1.91 2010/10/24 13:53:44 gruberroland Exp $
 
   This code is part of LDAP Account Manager (http://www.ldap-account-manager.org/)
   Copyright (C) 2004 - 2010  Roland Gruber
@@ -68,6 +68,7 @@ if (isset($_GET['getCSV'])) {
 }
 
 include 'main_header.php';
+echo '<div class="userlist-bright smallPaddingContent">';
 
 // get possible types and remove those which do not support file upload
 $types = $_SESSION['config']->get_ActiveTypes();
@@ -107,7 +108,9 @@ if (isset($_POST['type'])) {
 }
 
 // show start page
-echo "<h1>" . _("Account creation via file upload") . "</h1>\n";
+echo "<div class=\"title\">\n";
+echo "<h2 class=\"titleText\">" . _("Account creation via file upload") . "</h2>\n";
+echo "</div>";
 echo "<p>&nbsp;</p>\n";
 
 echo "<p>\n";
@@ -116,13 +119,6 @@ echo "</p>\n";
 
 echo "<p>&nbsp;</p>\n";
 
-echo '<script type="text/javascript">';
-echo 'function changeVisibleModules(element) {';
-echo 'jQuery(\'div.typeOptions\').toggle(false);';
-echo 'jQuery(\'div#\' + element.options[element.selectedIndex].value).toggle();';
-echo '}';
-echo '</script>';
-
 echo "<form enctype=\"multipart/form-data\" action=\"masscreate.php\" method=\"post\">\n";
 
 echo "<table style=\"border-color: grey\" cellpadding=\"10\" border=\"0\" cellspacing=\"0\">\n";
@@ -192,14 +188,24 @@ echo "<table style=\"border-color: grey\" cellpadding=\"10\" border=\"0\" cellsp
 	}
 	echo "</td></tr>\n";
 	echo "<tr><td>\n";
-		echo "<input class=\"user\" type=\"submit\" name=\"submit\" value=\"". _("Ok") . "\">\n";
+		echo "<button id=\"okButton\" class=\"smallPadding\" name=\"submit\">". _("Ok") . "</button>\n";
+		?>
+		<script type="text/javascript">
+		jQuery(document).ready(function() {
+			jQuery('#okButton').button();
+		});
+		function changeVisibleModules(element) {
+			jQuery('div.typeOptions').toggle(false);
+			jQuery('div#' + element.options[element.selectedIndex].value).toggle();
+		}
+		</script>
+		<?php
 	echo "</td></tr>\n";
 echo "</table>\n";
 echo "</form>\n";
 
-echo "</body>\n";
-echo "</html>\n";
-
+echo '</div>';
+include 'main_footer.php';
 
 /**
 * Displays the acount type specific main page of the upload.
@@ -222,12 +228,21 @@ function showMainPage($scope, $selectedModules) {
 	echo "<form enctype=\"multipart/form-data\" action=\"massBuildAccounts.php\" method=\"post\">\n";
 	echo "<p>\n";
 	echo "<b>" . _("CSV file:") . "</b> <input class=\"$scope\" name=\"inputfile\" type=\"file\">&nbsp;&nbsp;";
-	echo "<input class=\"$scope\" name=\"submitfile\" type=\"submit\" value=\"" . _('Upload file and create accounts') . "\">\n";
+	echo "<button class=\"smallPadding\" name=\"submitfile\" id=\"okButton\">" . _('Upload file and create accounts') . "</button>\n";
 	echo "<input type=\"hidden\" name=\"scope\" value=\"$scope\">\n";
 	echo "<input type=\"hidden\" name=\"selectedModules\" value=\"" . implode(',', $selectedModules) . "\">\n";
+	echo "&nbsp;&nbsp;&nbsp;&nbsp;<a href=\"masscreate.php?getCSV=1\"><b>" . _("Download sample CSV file") . "</b></a>\n";
 	echo "</p>\n";
 	echo "</form>\n";
 
+	?>
+	<script type="text/javascript">
+	jQuery(document).ready(function() {
+		jQuery('#okButton').button();
+	});
+	</script>
+	<?php
+	
 	echo "<p>&nbsp;</p>\n";
 	
 	echo _("Here is a list of possible columns. The red columns must be included in the CSV file and filled with data for all accounts.");
@@ -308,69 +323,35 @@ function showMainPage($scope, $selectedModules) {
 		echo "</fieldset><br>";
 	}
 
-	echo "<p>&nbsp;</p>\n";
-
-	// print table example and build sample CSV
+	// build sample CSV
 	$sampleCSV_head = array();
 	$sampleCSV_row = array();
-	echo "<big><b>" . _("This is an example how it would look in your spreadsheet program before you convert to CSV:") . "</b></big><br><br>\n";
-
-	echo "<table style=\"border-color: grey\" cellpadding=\"10\" border=\"2\" cellspacing=\"0\">\n";
-		echo "<tr>\n";
-			// DN attributes
-			$sampleCSV_head[] = "\"dn_suffix\"";
-			$sampleCSV_head[] = "\"dn_rdn\"";
-			echo "<td>\n";
-				echo "dn_suffix";
-			echo "</td>\n";
-			echo "<td>\n";
-				echo "dn_rdn";
-			echo "</td>\n";
-			// module attributes
-			for ($m = 0; $m < sizeof($modules); $m++) {
-				if (sizeof($columns[$modules[$m]]) < 1) continue;
-				for ($i = 0; $i < sizeof($columns[$modules[$m]]); $i++) {
-					$sampleCSV_head[] = "\"" . $columns[$modules[$m]][$i]['name'] . "\"";
-					echo "<td>\n";
-						echo $columns[$modules[$m]][$i]['name'];
-					echo "</td>\n";
-				}
+		// DN attributes
+		$sampleCSV_head[] = "\"dn_suffix\"";
+		$sampleCSV_head[] = "\"dn_rdn\"";
+		// module attributes
+		for ($m = 0; $m < sizeof($modules); $m++) {
+			if (sizeof($columns[$modules[$m]]) < 1) continue;
+			for ($i = 0; $i < sizeof($columns[$modules[$m]]); $i++) {
+				$sampleCSV_head[] = "\"" . $columns[$modules[$m]][$i]['name'] . "\"";
 			}
-		echo "</tr>\n";
-		echo "<tr>\n";
-			$RDNs = getRDNAttributes($scope, $selectedModules);
-			// DN attributes
-			$sampleCSV_row[] = "\"" . $_SESSION['config']->get_Suffix($scope) . "\"";
-			$sampleCSV_row[] = "\"" . $RDNs[0] . "\"";
-			echo "<td>\n";
-				echo $_SESSION['config']->get_Suffix($scope);
-			echo "</td>\n";
-			echo "<td>\n";
-				echo $RDNs[0];
-			echo "</td>\n";
-			// module attributes
-			for ($m = 0; $m < sizeof($modules); $m++) {
-				if (sizeof($columns[$modules[$m]]) < 1) continue;
-				for ($i = 0; $i < sizeof($columns[$modules[$m]]); $i++) {
-					$sampleCSV_row[] = "\"" . $columns[$modules[$m]][$i]['example'] . "\"";
-					echo "<td>\n";
-						echo $columns[$modules[$m]][$i]['example'];
-					echo "</td>\n";
-				}
+		}
+		$RDNs = getRDNAttributes($scope, $selectedModules);
+		// DN attributes
+		$sampleCSV_row[] = "\"" . $_SESSION['config']->get_Suffix($scope) . "\"";
+		$sampleCSV_row[] = "\"" . $RDNs[0] . "\"";
+		// module attributes
+		for ($m = 0; $m < sizeof($modules); $m++) {
+			if (sizeof($columns[$modules[$m]]) < 1) continue;
+			for ($i = 0; $i < sizeof($columns[$modules[$m]]); $i++) {
+				$sampleCSV_row[] = "\"" . $columns[$modules[$m]][$i]['example'] . "\"";
 			}
-		echo "</tr>\n";
-	echo "</table>\n";
+		}
 	$sampleCSV = implode(",", $sampleCSV_head) . "\n" . implode(",", $sampleCSV_row) . "\n";
 	$_SESSION['mass_csv'] = $sampleCSV;
 	
-	// link to CSV sample
-	echo "<p>\n";
-	echo "<br><br>\n";
-	echo "<a href=\"masscreate.php?getCSV=1\"><b>" . _("Download sample CSV file") . "</b></a>\n";
-	echo "<br><br>\n";
-
-	echo "</body>\n";
-	echo "</html>\n";
+	echo '</div>';
+	include 'main_footer.php';
 	die;
 }
 
